@@ -47,12 +47,13 @@ exports.serve = function (nylon_path, port) {
         cluster.on('exit', (worker, code, signal) => {
             console.log("code::" + code);
             console.log("signal::" + signal);
-            // if (code != 255) {
-            cluster.fork();
-            logger.info('worker ' + worker.process.pid + ' died');
-            //}else{
-            //  process.exit(0);
-            // }
+            if (code != 255) {
+                cluster.fork();
+                logger.info('worker ' + worker.process.pid + ' died');
+            }else{
+              process.exit();
+              return;
+            }
 
         });
 
@@ -60,7 +61,8 @@ exports.serve = function (nylon_path, port) {
             for (worker in cluster.workers) {
                 cluster.workers[worker].kill();
             }
-            process.exit(0);
+            process.exit();
+            return;
         });
         //  cluster.on('online', (worker) => {
         //console.log(process.cwd());
