@@ -13,9 +13,9 @@ var java = require('java');
 //var logger = require('winston');
 var async = require('async');
 var fscan = require('./../common/fscan');
-var looger;
+//var looger;
 module.exports = function (app) {
-    logger=app.nylon.logger;
+    var logger=app.nylon.logger;
     try {
         fscan.scan(app.nylon.nylon_path + "/java", '.jar', true, function (err, jars) {
             if(!err){
